@@ -154,7 +154,7 @@ int Examine(mddev_dev_t devlist, int brief, char *conffile)
 			printf("  Creation Time : %.24s\n", ctime(&atime));
 			c=map_num(pers, super.level);
 			printf("     Raid Level : %s\n", c?c:"-unknown-");
-			printf("    Device Size : %d%s\n", super.size, human_size(super.size));
+			printf("    Device Size : %d%s\n", super.size, human_size((long long)super.size<<10));
 			printf("     Raid Disks : %d\n", super.raid_disks);
 			printf("    Total Disks : %d\n", super.nr_disks);
 			printf("Preferred Minor : %d\n", super.md_minor);
